==> zego_uikit_prebuilt_live_streaming-3.1.7.tar.gz: README.md <==


# Live Streaming Kit

**Live Streaming Kit** is a feature-rich livestream component, which enables you to build custom live streaming into your apps with only a few lines of code. 

And you can also customize various live streaming features by configuring parameters.

> 
>
>If you find this package helpful, please help by giving it a 👍 on pub.dev! ↗️
>
>Your support and encouragement motivate us to continue improving and maintaining this package.
>
>Thank you for recognizing our work! 👏👏

---

[![ZEGOCLOUD Live Streaming Feature Intro](https://res.cloudinary.com/marcomontalbano/image/upload/v1682408345/video_to_markdown/images/youtube--yt3NkjIBoMA-c05b58ac6eb4c4700831b2b3070cd403.jpg)](https://www.youtube.com/embed/yt3NkjIBoMA "ZEGOCLOUD Live Streaming Feature Intro")

## When do you need the Live Streaming Kit
- Build apps faster and easier
  - When you want to prototype live streaming ASAP
  - Consider speed or efficiency as the first priority
- Customize UI as needed
  - When you want to customize the UI based on your actual business needs
  - Don't want to waste time developing basic features

## Features
- Ready-to-use live streaming
- Co-hosting (make co-host & apply co-host)
- PK
- Voice changing & Reverb
- Basic face beautification
- Screen sharing
- Customizable UI style
- Real-time interactive text chat
- Real-time audience capacity display
- Device management
- Extendable menu bar


## Documentation

- [APIs](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/APIs-topic.html)
- [Events](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Events-topic.html)
- [Configs](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/zego_uikit_prebuilt_live_streaming/ZegoUIKitPrebuiltLiveStreamingConfig-class.html)

> 
> 

- [Quick start](https://docs.zegocloud.com/article/14846)
- [Quick start (with cohosting)](https://docs.zegocloud.com/article/14882)
- [Tutorial navigator](https://docs.zegocloud.com/article/15804)
- Enhance the livestream
  - [PK battles](https://docs.zegocloud.com/article/15580)
  - [Screen sharing](https://docs.zegocloud.com/article/15641)
  - [Advanced beauty effects](https://docs.zegocloud.com/article/15975)
  - [Minimize livestream window](https://docs.zegocloud.com/article/16190)
  - [Send virtual gifts](https://docs.zegocloud.com/article/16201)
  - [Integrate Minigame](https://docs.zegocloud.com/article/16481)
- Customize the livestream
  - [Set avatar for users](https://docs.zegocloud.com/article/16307)
  - [Hide components](https://docs.zegocloud.com/article/16306)
  - [Customize the preview page](https://docs.zegocloud.com/article/16305)
  - [Set a leave confirmation dialog](https://docs.zegocloud.com/article/16309)
  - [Customize the background](https://docs.zegocloud.com/article/16311)
  - [Add custom UI components](https://docs.zegocloud.com/article/16313)
  - [Customize the text message UI](https://docs.zegocloud.com/article/16315)
  - [Customize the member list view](https://docs.zegocloud.com/article/16317)
  - [Modify User Interface text](https://docs.zegocloud.com/article/16319)
  - [Customize the menu bar](https://docs.zegocloud.com/article/16321)
  - [Implement an audio-only live](https://docs.zegocloud.com/article/16323)
  - [Forcefully end a livestream room](https://docs.zegocloud.com/article/16325)
  - [Turn off camera during co-hosting](https://docs.zegocloud.com/article/16329)
  - [Set video resolution](https://docs.zegocloud.com/article/16331)
  - [Limit the maximum number of co-hosts](https://docs.zegocloud.com/article/16333)
  - [Host Avatar](https://docs.zegocloud.com/article/16335)
  - [Calculate live duration](https://docs.zegocloud.com/article/16082)
  - [Customize The CoHosting](https://docs.zegocloud.com/article/16410)
  - [Swipe Live Streaming](https://docs.zegocloud.com/article/16478)
  - [Customize the layout](https://docs.zegocloud.com/article/16484)
- [FAQs](https://docs.zegocloud.com/article/15815)

## Migration Guides

- [Migrating from 3.1.1 to 3.1.2](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Migration:%20v3.0-topic.html#312).
- [Migrating from 2.x to 3.0](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Migration:%20v3.0-topic.html#30).

## More

[Sample Code](https://github.com/ZEGOCLOUD/zego_uikit_prebuilt_live_streaming_example_flutter)

<br />

[Please visit our official website for more details.](https://docs.zegocloud.com/article/14874)

==> zego_uikit_prebuilt_live_streaming-3.4.1.tar.gz: README.md <==


# Live Streaming Kit

**Live Streaming Kit** is a feature-rich livestream component, which enables you to build custom live streaming into your apps with only a few lines of code. 

And you can also customize various live streaming features by configuring parameters.

> 
>
>If you find this package helpful, please help by giving it a 👍 on pub.dev! ↗️
>
>Your support and encouragement motivate us to continue improving and maintaining this package.
>
>Thank you for recognizing our work! 👏👏

---

[![ZEGOCLOUD Live Streaming Feature Intro](https://res.cloudinary.com/marcomontalbano/image/upload/v1682408345/video_to_markdown/images/youtube--yt3NkjIBoMA-c05b58ac6eb4c4700831b2b3070cd403.jpg)](https://www.youtube.com/embed/yt3NkjIBoMA "ZEGOCLOUD Live Streaming Feature Intro")

## When do you need the Live Streaming Kit
- Build apps faster and easier
  - When you want to prototype live streaming ASAP
  - Consider speed or efficiency as the first priority
- Customize UI as needed
  - When you want to customize the UI based on your actual business needs
  - Don't want to waste time developing basic features

## Features
- Ready-to-use live streaming
- Co-hosting (make co-host & apply co-host)
- PK
- Voice changing & Reverb
- Basic face beautification
- Screen sharing
- Customizable UI style
- Real-time interactive text chat
- Real-time audience capacity display
- Device management
- Extendable menu bar


## Documentation

- [APIs](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/APIs-topic.html)
- [Events](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Events-topic.html)
- [Configs](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/zego_uikit_prebuilt_live_streaming/ZegoUIKitPrebuiltLiveStreamingConfig-class.html)

> 
> 

- [Quick start](https://docs.zegocloud.com/article/14846)
- [Quick start (with cohosting)](https://docs.zegocloud.com/article/14882)
- [Tutorial navigator](https://docs.zegocloud.com/article/15804)
- Enhance the livestream
  - [PK battles](https://docs.zegocloud.com/article/15580)
  - [Screen sharing](https://docs.zegocloud.com/article/15641)
  - [Advanced beauty effects](https://docs.zegocloud.com/article/15975)
  - [Minimize livestream window](https://docs.zegocloud.com/article/16190)
  - [Send virtual gifts](https://docs.zegocloud.com/article/16201)
  - [Integrate Minigame](https://docs.zegocloud.com/article/16481)
- Customize the livestream
  - [Set avatar for users](https://docs.zegocloud.com/article/16307)
  - [Hide components](https://docs.zegocloud.com/article/16306)
  - [Customize the preview page](https://docs.zegocloud.com/article/16305)
  - [Set a leave confirmation dialog](https://docs.zegocloud.com/article/16309)
  - [Customize the background](https://docs.zegocloud.com/article/16311)
  - [Add custom UI components](https://docs.zegocloud.com/article/16313)
  - [Customize the text message UI](https://docs.zegocloud.com/article/16315)
  - [Customize the member list view](https://docs.zegocloud.com/article/16317)
  - [Modify User Interface text](https://docs.zegocloud.com/article/16319)
  - [Customize the menu bar](https://docs.zegocloud.com/article/16321)
  - [Implement an audio-only live](https://docs.zegocloud.com/article/16323)
  - [Forcefully end a livestream room](https://docs.zegocloud.com/article/16325)
  - [Turn off camera during co-hosting](https://docs.zegocloud.com/article/16329)
  - [Set video resolution](https://docs.zegocloud.com/article/16331)
  - [Limit the maximum number of co-hosts](https://docs.zegocloud.com/article/16333)
  - [Host Avatar](https://docs.zegocloud.com/article/16335)
  - [Calculate live duration](https://docs.zegocloud.com/article/16082)
  - [Customize The CoHosting](https://docs.zegocloud.com/article/16410)
  - [Swipe Live Streaming](https://docs.zegocloud.com/article/16478)
  - [Customize the layout](https://docs.zegocloud.com/article/16484)
- [FAQs](https://docs.zegocloud.com/article/15815)

## Migration Guides

- [Migrating from 3.1.1 to 3.1.2](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Migration_v3.x-topic.html#312).
- [Migrating from 2.x to 3.0](https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Migration_v3.x-topic.html#30).

## More

[Sample Code](https://github.com/ZEGOCLOUD/zego_uikit_prebuilt_live_streaming_example_flutter)

<br />

[Please visit our official website for more details.](https://docs.zegocloud.com/article/14874)
